#
# spec file for package python-elasticsearch-dsl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-elasticsearch-dsl
Version:        8.17.0
Release:        1.1
Summary:        Python client for Elasticsearch
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/elasticsearch/elasticsearch-dsl-py
Source:         https://github.com/elastic/elasticsearch-dsl-py/archive/refs/tags/v%{version}.tar.gz#/elasticsearch-dsl-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# gh#elastic/elasticsearch-dsl-py#1569
Requires:       python-elasticsearch >= 8.0.0
Requires:       python-elastic-transport >= 8.0.0
Requires:       python-python-dateutil
Requires:       python-typing_extensions
Suggests:       python-pytz
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module elasticsearch >= 8.0.0}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module nltk}
BuildRequires:  %{python_module pytest >= 3.0.0}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module sqlite3}
# /SECTION
%python_subpackages

%description
Python client for Elasticsearch.

%prep
%autosetup -p1 -n elasticsearch-dsl-py-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Requires nltk wordnet
%pytest --ignore tests/test_integration/test_examples/_async/test_vectors.py --ignore tests/test_integration/test_examples/_sync/test_vectors.py

%files %{python_files}
%doc AUTHORS Changelog.rst README
%license LICENSE
%{python_sitelib}/elasticsearch_dsl
%{python_sitelib}/elasticsearch_dsl-%{version}.dist-info

%changelog
* Wed Jan  8 2025 Daniel Garcia <daniel.garcia@suse.com>
- Update to 8.17.0:
  * Added support for quantized dense vector options (#1948)
  * Added support for composable index templates (#1943)
- 8.16.0:
  * Autogenerate parts of the library using documentation and types from the Elasticsearch specification
  - query classes (#1890)
  - aggregation classes (#1918)
  - response classes (#1929 #1932)
  * Support pipe syntax to declare optional document fields (#1937)
  * Ignore document attributes typed with ClassVar (#1936)
  * Support Python 3.13 (#1938)
- 8.15.4:
  * Fixed the use of dictionaries as values in Terms query (#1920)
- 8.15.3:
  * Fixed regression introduced in Terms query class (#1907)
  * Removed unnecessary filter argument in AggBase.__getitem__ (#1903)
  * Fixed deserialization of datetime.date fields (#1914)
- 8.15.2:
  * Added support for any iterables to the Terms query (#1887)
  * Added back support for tuples and other iterables to Search.source() method (#1895)
  * Added recursive option to AttrDict.to_dict() (#1892)
  * Removed unused analyzer from search as you type example (#1883)
- 8.15.1:
  * Added support for the semantic_text field and semantic query type (#1881)
  * Removed extra __orig_class__ attribute in aggregation responses (#1877)
- 8.15.0:
  * Added the option to use Python types to declare document fields (#1845)
  * Added type annotations (#1533)
  * Added support for bulk document operations with Document.bulk() (#1864)
  * Added the ConstantKeyword field to the top-level package (#1843)
  * Added async_connections to the top-level package (#1865)
  * Added index creation to the aggregations example (#1862)
- 8.14.0:
  * Added text_expansion query clause (#1837)
  * Added Response.search_after() and Search.search_after() methods for efficient iteration (#1829)
  * Added point in time support and the iterate() method in the Search class (#1833)
  * Added support for slicing multiple times in Search class (#1771)
  * Added support for regular expressions in Completion.suggest() (#1836)
  * Fixed suggest() method of the Completion class to format requests correctly. (#1836)
  * Fixed Document.update() to accept fields set to None or empty (#1820)
  * Started work on type hints (Thanks Caio Fontes for leading this effort!)
  - Added Type hints to function.py (#1827)
  - Added Type hints to query.py (#1821)
- 8.13.1:
  * Added support for knn as a query option (#1770)
  * Made the dims attribute of the dense vector type optional (#1776)
  * Added missing inner_hits option to search.knn() method (#1777)
  * Added support for detecting document updates in InnerDoc attributes (#1535)
  * Changed _expand__to_dot setting to resolve at runtime (#1633)
  * Added explicit error message when unsupported minimum_should_match values are used (#1774)
  * Added the EmptySearch class (#1780)
  * Added several missing aggregations:
  - AdjacencyMatrix (#1553)
  - CategorizeText (#1588)
  - GeohexGrid (#1590)
  - IPPrefix (#1592)
  - RandomSampler (#1594)
  - GeoLine (#1628)
  - MatrixStats (#1630)
  - TopMetrics (#1706)
  * Added params option to the FacetedSearch object (#1500)
  * Added support for passing a dictionary in the script option for a document update (#1560)
  * Added keys() and items() methods to AttrDict class (#1784)
  * Added a to_list() method to the AttrList class (#1584)
  * Fixed various documentation issues and typos (#1769, #1615, #1585, #1318, #1223)
  * Added a vector search example (#1778)
- 8.13.0:
  * Added asyncio support (#1714)
  * Dropped support for Python 3.7 (#1717)
  * Stopped mixing body and parameters in UpdateByQuery (#1702)
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 8.12.0:
  * Added Search.knn() method
  * Added Search.rank() method (undocumented as it still is in
    technical preview)
  * Fixed importing collapse from dictionary
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 8.11.0:
  * Added support for Python 3.12
  * Added support for Search.collase()
* Fri Sep  1 2023 Matej Cepl <mcepl@suse.com>
- Update to 8.9.0:
  - Added Elasticsearch 8.x support
  - Dropped support for Python 2.7 and 3.5
  - Added support for Python 3.10 and 3.11
  - Added the MultiTerms aggregation
  - Added the CombinedFields query
- Remove upstreamed python-elasticsearch-dsl-no-mock.patch.
* Wed May 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Delete drop-python2-support.patch
- Update to 7.4.1:
  * Fixed DeprecationWarnings that would be emitted from deprecated
    usages of the body parameter in the Python Elasticsearch client.
* Mon Nov 28 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add drop-python2-support.patch from upstream
  gh#elastic/elasticsearch-dsl-py@f7f85a5db8f2
- Remove python-six dependency
* Tue Oct 18 2022 Matej Cepl <mcepl@suse.com>
- Update to 7.4.0:
  - Added the ConstantKeyword, RankFeatures field types
  - Added the ScriptScore query type
  - Added UpdateByQueryResponse.success() method
  - Added return_doc_meta parameter to Document.save() and
    Document.update() for accessing the complete API response
  - Added support for calendar_interval and fixed_interval to
    DateHistogramFacet
  - Added Document.exists() method
  - Added support for the year interval to DateHistogramFacet
  - Fixed issue where to_dict() should be called recursively on
    Search.extras and **kwargs
  - Fixed inverse of an empty Bool query should be MatchNone
  - Fixed issue between retry_on_conflict and optimistic
    concurrency control within Document.update()
- Update to 7.3.0:
  - Added Intervals, MatchBoolPrefix, Shape, and Wrapper queries
  - Added Boxplot, RareTerms, VariableWidthHistogram,
    MedianAbsoluteDeviation, TTest, CumulativeCardinality,
    Inference, MovingPercentiles, and Normalize aggregations
  - Added __all__ and removed all star imports from
    elasticsearch_dsl namespace to avoid leaking unintended names
  - Fixed an issue where Object and Nested could mutate the inner
    doc_class mapping
  - Fixed a typo in query SpanContaining, previously was
    SpanContainining
- Limit required (and buildrequired) elasticsearch to < 8
  (gh#elastic/elasticsearch-dsl-py#1569).
* Mon May 23 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/elastic/elasticsearch-dsl-py/issues/1596
  + python-elasticsearch-dsl-no-mock.patch
* Fri Nov 27 2020 John Vandenberg <jayvdb@gmail.com>
- Resume builds by removing unnecessary build dependency coverage < 5
* Thu Aug 20 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v7.2.1
* Tue Jul 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v7.0.0
